==========
vdirsyncer
==========

- `Documentation <https://vdirsyncer.pimutils.org/en/stable/>`_
- `Source code <https://github.com/pimutils/vdirsyncer>`_

Vdirsyncer synchronizes your calendars and addressbooks between two storages_.
The most popular purpose is to synchronize a CalDAV/CardDAV server with a local
folder or file. The local data can then be accessed via a variety of programs_,
none of which have to know or worry about syncing to a server.

.. _storages: https://vdirsyncer.pimutils.org/en/latest/config.html#storages
.. _programs: https://vdirsyncer.pimutils.org/en/stable/supported.html

It aims to be for CalDAV and CardDAV what `OfflineIMAP
<http://offlineimap.org/>`_ is for IMAP.

.. image:: https://travis-ci.org/pimutils/vdirsyncer.png?branch=master
    :target: https://travis-ci.org/pimutils/vdirsyncer

.. image:: https://codecov.io/github/pimutils/vdirsyncer/coverage.svg?branch=master
    :target: https://codecov.io/github/pimutils/vdirsyncer?branch=master

.. image:: https://badge.waffle.io/pimutils/vdirsyncer.svg?label=ready&title=Ready
    :target: https://waffle.io/pimutils/vdirsyncer

Links of interest
=================

* Check out `the tutorial
  <https://vdirsyncer.pimutils.org/en/stable/tutorial.html>`_ for basic
  usage.

* `Contact information
  <https://vdirsyncer.pimutils.org/en/stable/contact.html>`_

* `How to contribute to this project
  <https://vdirsyncer.pimutils.org/en/stable/contributing.html>`_

License
=======

Licensed under the Expat/MIT license, see ``LICENSE``.

Donations
=========

If you found my work useful, please consider donating. Thank you!

- Bitcoin: ``16sSHxZm263WHR9P9PJjCxp64jp9ooXKVt``

- `PayPal.me <https://www.paypal.me/untitaker>`_

- Bountysource is useful for funding work on a specific GitHub issue:

  .. image:: https://img.shields.io/bountysource/team/vdirsyncer/activity.svg
      :target: https://www.bountysource.com/teams/vdirsyncer

  - There's also Bountysource `Salt
    <https://salt.bountysource.com/teams/vdirsyncer>`_, for one-time and
    recurring donations.


- Flattr can be used for recurring donations:

  .. image:: https://api.flattr.com/button/flattr-badge-large.png
      :target: https://flattr.com/submit/auto?user_id=untitaker&url=https%3A%2F%2Fgithub.com%2Fpimutils%2Fvdirsyncer

- Gratipay can be used for recurring donations:

  .. image:: https://img.shields.io/gratipay/team/vdirsyncer.svg
      :target: https://gratipay.com/vdirsyncer/
